@@ -1,25 +1,24 @@
 
 # imports
 from syst3m.classes.config import *
-from syst3m.classes import objects, defaults
 
 # utils.
 def check_os(supported=["linux"], error=False):
 	if OS not in supported:
 		if error: raise ValueError(f"Unsupported operating system: {OS}.")
-		else: return r3sponse.error(f"Unsupported operating system: {OS}.")
+		else: return Response.error(f"Unsupported operating system: {OS}.")
 	else:
 		if error: return None
-		else: return r3sponse.success(f"Supported operating system: {OS}.")
+		else: return Response.success(f"Supported operating system: {OS}.")
 def coming_soon():
 	raise ValueError("COMING SOON.")
 
 # the disks object class.
-class Disks(objects.Object):
+class Disks(Object):
 	def __init__(self):
 		
-		# defaults.
-		objects.Object.__init__(self, traceback="syst3m.disks")
+		# Defaults.
+		Object.__init__(self, traceback="syst3m.disks")
 
 		#
 	def list(self):
@@ -36,19 +35,19 @@ class Disks(objects.Object):
 	):
 
 		# check parameters.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"device:str":device,})
 		if not response.success: return response
 
 		# check os.
-		if defaults.vars.os not in ["linux"]:
-			return r3sponse.error(f"Unsupported operating system [{defaults.vars.os}].")
+		if Defaults.vars.os not in ["linux"]:
+			return Response.error(f"Unsupported operating system [{Defaults.vars.os}].")
 
 		# handler.
 		if "SUCCESS!" in output:
-			return r3sponse.success(f"Successfully erase device {device}.")
+			return Response.success(f"Successfully erase device {device}.")
 		else:
-			return r3sponse.error(f"Failed to erase device {device}, output: {output}")
+			return Response.error(f"Failed to erase device {device}, output: {output}")
 
 		#
 	def partition(self, 
@@ -57,7 +56,7 @@ class Disks(objects.Object):
 	):
 		coming_soon()
 		# check parameters.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"device:str":device,})
 		if not response.success: return response
 
@@ -73,9 +72,9 @@ class Disks(objects.Object):
 		
 		# handler.
 		if "SUCCESS!" in output:
-			return r3sponse.success(f"Successfully partitioned device {device}.")
+			return Response.success(f"Successfully partitioned device {device}.")
 		else:
-			return r3sponse.error(f"Failed to partition device {device}, output: {output}")
+			return Response.error(f"Failed to partition device {device}, output: {output}")
 
 		#
 	def format(self, 
@@ -86,7 +85,7 @@ class Disks(objects.Object):
 	):
 		coming_soon()
 		# check parameters.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"device:str":device,
 			"label:str":label,})
 		if not response.success: return response
@@ -97,9 +96,9 @@ class Disks(objects.Object):
 
 		# handler.
 		if "SUCCESS!" in output:
-			return r3sponse.success(f"Successfully formatted device {device}.")
+			return Response.success(f"Successfully formatted device {device}.")
 		else:
-			return r3sponse.error(f"Failed to format device {device}, output: {output}")
+			return Response.error(f"Failed to format device {device}, output: {output}")
 
 		#
 	def mount(self, 
@@ -110,7 +109,7 @@ class Disks(objects.Object):
 	):
 		coming_soon()
 		# check parameters.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"device:str":device,
 			"path:str":path,})
 		if not response.success: return response
@@ -121,9 +120,9 @@ class Disks(objects.Object):
 
 		# handler.
 		if "SUCCESS!" in output:
-			return r3sponse.success(f"Successfully mounted device {device} to {path}.")
+			return Response.success(f"Successfully mounted device {device} to {path}.")
 		else:
-			return r3sponse.error(f"Failed to mount device {device} to {path}, output: {output}")
+			return Response.error(f"Failed to mount device {device} to {path}, output: {output}")
 
 		#
 	def unmount(self, 
@@ -132,7 +131,7 @@ class Disks(objects.Object):
 	):
 		coming_soon()
 		# check parameters.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"path:str":path,})
 		if not response.success: return response
 		
@@ -142,9 +141,9 @@ class Disks(objects.Object):
 
 		# handler.
 		if "SUCCESS!" in output:
-			return r3sponse.success(f"Successfully unmounted path {path}.")
+			return Response.success(f"Successfully unmounted path {path}.")
 		else:
-			return r3sponse.error(f"Failed to unmount path {path}, output: {output}")
+			return Response.error(f"Failed to unmount path {path}, output: {output}")
 
 		#
 
