@@ -3,10 +3,10 @@
 
 # imports.
 from syst3m.classes.config import *
-from syst3m.classes import utils, console, defaults, objects
+from syst3m.classes import utils, console
 
 # the service object class.
-class Service(objects.Object):
+class Service(Object):
 	# launchd: 
 	# 	$ tail -f /var/log/system.log
 	#	https://medium.com/swlh/how-to-use-launchd-to-run-services-in-macos-b972ed1e352
@@ -37,8 +37,8 @@ class Service(objects.Object):
 		traceback="syst3m.service.Service",
 	):	
 
-		# defaults.
-		objects.Object.__init__(self, traceback=traceback)
+		# Defaults.
+		Object.__init__(self, traceback=traceback)
 
 		# vars.
 		self.id = id
@@ -67,7 +67,7 @@ class Service(objects.Object):
 			if self.errors.fp.exists(): self.errors.load()
 
 		# attributes.
-		if defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 			self.service = File(path=f"/Library/LaunchDaemons/{self.id}.plist")
 		else:
 			self.service = File(path=f"/etc/systemd/system/{self.id}.service")
@@ -77,7 +77,7 @@ class Service(objects.Object):
 	def create(self):
 
 		# check params.
-		response = r3sponse.parameters.check(
+		response = Response.parameters.check(
 			traceback=self.__traceback__(function="create"),
 			parameters={
 				"id":self.id,
@@ -88,25 +88,25 @@ class Service(objects.Object):
 
 		# checks.
 		if self.service.fp.exists(): 
-			return r3sponse.error(f"Service [{self.service.fp.path}] already exists (call service.check() instead).")
+			return Response.error(f"Service [{self.service.fp.path}] already exists (call service.check() instead).")
 
 		# save.
-		r3sponse.log(f"&ORANGE&Root permission&END& required to save changes to [{self.service.fp}].", log_level=self.log_level)
+		Response.log(f"&ORANGE&Root permission&END& required to save changes to [{self.service.fp}].", log_level=self.log_level)
 		self.service.save(data=self.__create__(), sudo=True)
 		self.service.fp.ownership.set("root", sudo=True)
 		self.service.fp.permission.set(700, sudo=True)
 
 		# handler.
 		if self.service.fp.exists(): 
-			return r3sponse.success(f"Successfully created service {self.id}.")
+			return Response.success(f"Successfully created service {self.id}.")
 		else:
-			return r3sponse.error(f"Failed to create service {self.id}.")
+			return Response.error(f"Failed to create service {self.id}.")
 
 		#
 	def check(self):
 
 		# check params.
-		response = r3sponse.parameters.check(
+		response = Response.parameters.check(
 			traceback=self.__traceback__(function="check"),
 			parameters={
 				"id":self.id,
@@ -123,7 +123,7 @@ class Service(objects.Object):
 		self.service.load(sudo=True)
 		data = self.__create__()
 		if self.service.data != data:
-			r3sponse.log(f"&ORANGE&Root permission&END& required to save changes to [{self.service.fp}].", log_level=self.log_level)
+			Response.log(f"&ORANGE&Root permission&END& required to save changes to [{self.service.fp}].", log_level=self.log_level)
 			self.service.save(data=data, sudo=True)
 
 		# always set permissions.
@@ -132,32 +132,32 @@ class Service(objects.Object):
 		
 		# handler.
 		if self.service.fp.exists(): 
-			return r3sponse.success(f"Successfully checked service {self.id}.")
+			return Response.success(f"Successfully checked service {self.id}.")
 		else:
-			return r3sponse.error(f"Failed to check service {self.id}.")
+			return Response.error(f"Failed to check service {self.id}.")
 
 		#
 	def delete(self):
 
 		# checks.
 		if not self.service.fp.exists(): 
-			return r3sponse.error(f"Service [{self.service.fp.path}] does not already exist.")
+			return Response.error(f"Service [{self.service.fp.path}] does not already exist.")
 
 		# save.
 		self.service.fp.delete(sudo=True, forced=True)
 
 		# handler.
 		if not self.service.fp.exists(): 
-			return r3sponse.success(f"Successfully deleted service {self.id}.")
+			return Response.success(f"Successfully deleted service {self.id}.")
 		else:
-			return r3sponse.error(f"Failed to delete service {self.id}.")
+			return Response.error(f"Failed to delete service {self.id}.")
 
 		#
 	# control functions.
 	def start(self):
 		
 		# launchd.
-		if defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 			command = ""
 			for i in [self.id]:
 				command += f"sudo launchctl start {i} &&"
@@ -165,9 +165,9 @@ class Service(objects.Object):
 			output = console.execute(command)
 			if not output.success: return output
 			elif output.output in ["", "\n"]:
-				return r3sponse.success(f"Successfully started {self.id}.")
+				return Response.success(f"Successfully started {self.id}.")
 			else:
-				return r3sponse.error(f"Failed to start {self.id}.")
+				return Response.error(f"Failed to start {self.id}.")
 
 		# systemd.
 		else:
@@ -178,15 +178,15 @@ class Service(objects.Object):
 			output = console.execute(command)
 			if not output.success: return output
 			elif output.output in ["", "\n"]:
-				return r3sponse.success(f"Successfully started {self.id}.")
+				return Response.success(f"Successfully started {self.id}.")
 			else:
-				return r3sponse.error(f"Failed to start {self.id}.")
+				return Response.error(f"Failed to start {self.id}.")
 
 		#
 	def stop(self):
 		
 		# launchd.
-		if defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 			command = ""
 			for i in [self.id]:
 				command += f"sudo launchctl stop {i} &&"
@@ -194,9 +194,9 @@ class Service(objects.Object):
 			output = console.execute(command)
 			if not output.success: return output
 			elif output.output in ["", "\n"]:
-				return r3sponse.success(f"Successfully stopped {self.id}")
+				return Response.success(f"Successfully stopped {self.id}")
 			else:
-				return r3sponse.error(f"Failed to stop {self.id}")
+				return Response.error(f"Failed to stop {self.id}")
 
 		# systemd.
 		else:
@@ -207,20 +207,20 @@ class Service(objects.Object):
 			output = console.execute(command)
 			if not output.success: return output
 			elif output.output in ["", "\n"]:
-				return r3sponse.success(f"Successfully stopped {self.id}")
+				return Response.success(f"Successfully stopped {self.id}")
 			else:
-				return r3sponse.error(f"Failed to stop {self.id}")
+				return Response.error(f"Failed to stop {self.id}")
 
 		#
 	def restart(self):
 		
 		# launchd.
-		if defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 			response = self.stop()
 			if not response.success: return response
 			response = self.start()
 			if not response.success: return response
-			return r3sponse.success(f"Successfully restarted {self.id}")
+			return Response.success(f"Successfully restarted {self.id}")
 
 		# systemd.	
 		else:
@@ -231,19 +231,19 @@ class Service(objects.Object):
 			output = console.execute(command)
 			if not output.success: return output
 			elif output.output in ["", "\n"]:
-				return r3sponse.success(f"Successfully restarted {self.id}")
+				return Response.success(f"Successfully restarted {self.id}")
 			else:
-				return r3sponse.error(f"Failed to restarted {self.id}")
+				return Response.error(f"Failed to restarted {self.id}")
 
 		#
 	def status(self):
 		
 		# launchd.
-		if defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 			output = console.execute(f"sudo launchctl list | grep {self.id}")
 			if not output.success: return output
 			else:
-				return r3sponse.success(f"Successfully retrieved the status of {self.id}",{
+				return Response.success(f"Successfully retrieved the status of {self.id}",{
 					"status":output.output,
 				})
 
@@ -252,7 +252,7 @@ class Service(objects.Object):
 			output = console.execute(f"sudo systemctl status {self.id}")
 			if not output.success: return output
 			else:
-				return r3sponse.success(f"Successfully retrieved the status of {self.id}",{
+				return Response.success(f"Successfully retrieved the status of {self.id}",{
 					"status":output.output,
 				})
 
@@ -264,13 +264,13 @@ class Service(objects.Object):
 			self.logs.save(data="")
 		if "errors" in options:
 			self.logs.save(data="")
-		return r3sponse.success("Successfully resetted the logs.")
+		return Response.success("Successfully resetted the logs.")
 
 		#
 	def tail(self, global_=False, debug=False):
 			
 		# load logs.
-		if defaults.vars.os in ["macos"] and global_:
+		if Defaults.vars.os in ["macos"] and global_:
 				data = console.execute(f"cat /var/log/system.log | grep {self.id}")
 				if not data.success: return data
 				data = str(data)
@@ -280,7 +280,7 @@ class Service(objects.Object):
 			data = errors.load()
 		
 		# handler.
-		return r3sponse.success(f"Successfully tailed the {self.id} logs.", {
+		return Response.success(f"Successfully tailed the {self.id} logs.", {
 			"logs":data,
 		})
 
@@ -289,7 +289,7 @@ class Service(objects.Object):
 	def __create__(self):
 		
 		# lauchd.
-		if defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 
 			# checks.
 			if not isinstance(self.start_, (list, Array)): 
