@@ -4,7 +4,6 @@
 # imports.
 from syst3m.classes.config import *
 from syst3m.classes import utils, console
-from syst3m.classes.color import color, symbol
 
 """
 missing imports / variables:
@@ -19,7 +18,7 @@ def check_user(id, create=False):
 	if response["success"] and not response["exists"] and create: 
 		response = user.create()
 		if not response.success: return response
-	return r3sponse.success(f"Successfully checked user [{id}].")
+	return Response.success(f"Successfully checked user [{id}].")
 def check_group(id, users=[], create=False, overwrite=False):
 	group = Group(name=id, get_users=False)
 	response = group.check()
@@ -30,7 +29,7 @@ def check_group(id, users=[], create=False, overwrite=False):
 	elif overwrite:
 		response = group.check_users(users=users)
 		if not response.success: return response
-	return r3sponse.success(f"Successfully checked group [{id}].")
+	return Response.success(f"Successfully checked group [{id}].")
 
 
 # the user object.
@@ -53,11 +52,11 @@ class User(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		if l_response["exists"]:
-			return r3sponse.error(f"User [{self.username}] already exists.")
+			return Response.error(f"User [{self.username}] already exists.")
 
 		# check home dir.
 		if Files.exists(self.home_directory): 
-			return r3sponse.error(f"Home directory [{self.home_directory}] already exists.")
+			return Response.error(f"Home directory [{self.home_directory}] already exists.")
 
 		# handle linux.
 		if OS in ["linux"]:
@@ -66,14 +65,14 @@ class User(object):
 
 			# success.
 			if output == "":
-				return r3sponse.success(f"Successfully created user [{self.username}].")
+				return Response.success(f"Successfully created user [{self.username}].")
 
 			else:
-				return r3sponse.error(String(output.output.replace("useradd: ", "").replace("\n", ". ")).capitalized_word())
+				return Response.error(String(output.output.replace("useradd: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		
 		
@@ -85,7 +84,7 @@ class User(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		if not l_response["exists"]:
-			return r3sponse.error(f"User [{self.username}] does not exist.")
+			return Response.error(f"User [{self.username}] does not exist.")
 
 		# handle linux.
 		if OS in ["linux"]:
@@ -96,7 +95,7 @@ class User(object):
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# check.
 		l_response = self.check()
@@ -104,9 +103,9 @@ class User(object):
 		
 		# success.
 		if not l_response["exists"]:
-			return r3sponse.success(f"Successfully deleted user [{self.username}].")
+			return Response.success(f"Successfully deleted user [{self.username}].")
 		else:
-			return r3sponse.error(f"Failed to delete user [{self.username}].")
+			return Response.error(f"Failed to delete user [{self.username}].")
 
 		#
 	def check(self, silent=False):
@@ -121,10 +120,10 @@ class User(object):
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# success.
-		return r3sponse.success(f"Successfully checked user [{self.username}].", {
+		return Response.success(f"Successfully checked user [{self.username}].", {
 			"exists":exists,
 		})
 
@@ -145,16 +144,16 @@ class User(object):
 			
 			# success.
 			if "password updated successfully" in output:
-				return r3sponse.success(f"Successfully edited the password of user [{self.username}].")
+				return Response.success(f"Successfully edited the password of user [{self.username}].")
 
 			# fail.
 			else:
 				print(output)
-				return r3sponse.error(f"Failed to edit the password of user [{self.username}].")
+				return Response.error(f"Failed to edit the password of user [{self.username}].")
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		#
 	def add_groups(self, groups=[]):
@@ -169,7 +168,7 @@ class User(object):
 			l_response = group.check()
 			if l_response["error"] != None: return l_response
 			if not response["exists"]: 
-				return r3sponse.error(f"Group [{group.name}] does not exist.")
+				return Response.error(f"Group [{group.name}] does not exist.")
 
 			# add user.
 			l_response = group.add_users(users=[self.username])
@@ -178,7 +177,7 @@ class User(object):
 			#
 		
 		# success.
-		return r3sponse.success(f"Successfully added user to [{len(groups)}] groups.")
+		return Response.success(f"Successfully added user to [{len(groups)}] groups.")
 
 		#
 	def delete_groups(self, groups=[]):
@@ -189,7 +188,7 @@ class User(object):
 			l_response = group.check()
 			if l_response["error"] != None: return l_response
 			if not response["exists"]: 
-				return r3sponse.error(f"Group [{group.name}] does not exist.")
+				return Response.error(f"Group [{group.name}] does not exist.")
 
 			# delete user.
 			l_response = group.delete_users(users=[self.username])
@@ -197,7 +196,7 @@ class User(object):
 
 				
 		# success.
-		return r3sponse.success(f"Successfully added user to [{len(groups)}] groups.")
+		return Response.success(f"Successfully added user to [{len(groups)}] groups.")
 
 		#
 
@@ -233,7 +232,7 @@ class Group(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif l_response["exists"]:
-			return r3sponse.error(f"Group [{self.name}] already exists.")
+			return Response.error(f"Group [{self.name}] already exists.")
 
 		# handle linux.
 		if OS in ["linux"]:
@@ -241,14 +240,14 @@ class Group(object):
 
 			# success.
 			if output == "":
-				return r3sponse.success(f"Successfully created group [{self.name}].")
+				return Response.success(f"Successfully created group [{self.name}].")
 
 			else:
-				return r3sponse.error(String(output.output.replace("groupadd: ", "").replace("\n", ". ")).capitalized_word())
+				return Response.error(String(output.output.replace("groupadd: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		#
 	def delete(self):
@@ -257,7 +256,7 @@ class Group(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif l_response["exists"]:
-			return r3sponse.error(f"Group [{self.name}] already exists.")
+			return Response.error(f"Group [{self.name}] already exists.")
 
 		# handle linux.
 		if OS in ["linux"]:
@@ -265,15 +264,15 @@ class Group(object):
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# check existance.
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif l_response["exists"]:
-			return r3sponse.error(f"Failed to delete group [{self.name}].")
+			return Response.error(f"Failed to delete group [{self.name}].")
 		else:
-			return r3sponse.success(f"Successfully deleted group [{self.name}].")
+			return Response.success(f"Successfully deleted group [{self.name}].")
 
 
 		#
@@ -289,11 +288,11 @@ class Group(object):
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		
 		# success.
-		return r3sponse.success(f"Successfully checked group [{self.name}].", {
+		return Response.success(f"Successfully checked group [{self.name}].", {
 			"exists":exists,
 		})
 
@@ -304,7 +303,7 @@ class Group(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif not l_response["exists"]:
-			return r3sponse.error(f"Group [{self.name}] does not exists.")
+			return Response.error(f"Group [{self.name}] does not exists.")
 
 		# handle linux.
 		users = []
@@ -317,11 +316,11 @@ class Group(object):
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# success.
 		self.users = users
-		return r3sponse.success(f"Successfully listed all users {len(users)} of group [{self.name}].", {
+		return Response.success(f"Successfully listed all users {len(users)} of group [{self.name}].", {
 			"users":users,
 		})
 
@@ -332,21 +331,21 @@ class Group(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif not l_response["exists"]:
-			return r3sponse.error(f"Group [{self.name}] does not exists.")
+			return Response.error(f"Group [{self.name}] does not exists.")
 
 		# handle linux.
 		if OS in ["linux"]:
 			for user in users:
 				output = console.execute(f"sudo deluser {user} {self.name}")
 				if output != "":
-					return r3sponse.error(String(output.output.replace("deluser: ", "").replace("\n", ". ")).capitalized_word())
+					return Response.error(String(output.output.replace("deluser: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# success.
-		return r3sponse.success(f"Successfully deleted {len(users)} users from group [{self.name}].", {
+		return Response.success(f"Successfully deleted {len(users)} users from group [{self.name}].", {
 			"users":users,
 		})
 
@@ -357,7 +356,7 @@ class Group(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif not l_response["exists"]:
-			return r3sponse.error(f"Group [{self.name}] does not exists.")
+			return Response.error(f"Group [{self.name}] does not exists.")
 
 		# handle linux.
 		if OS in ["linux"]:
@@ -365,14 +364,14 @@ class Group(object):
 				output = console.execute(f"sudo usermod -a -G {self.name} {user}")
 				if not output.success: return output
 				if output.output != "":
-					return r3sponse.error(String(output.output.replace("usermod: ", "").replace("\n", ". ")).capitalized_word())
+					return Response.error(String(output.output.replace("usermod: ", "").replace("\n", ". ")).capitalized_word())
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# success.
-		return r3sponse.success(f"Successfully added {len(users)} users to group [{self.name}].", {
+		return Response.success(f"Successfully added {len(users)} users to group [{self.name}].", {
 			"users":users,
 		})
 
@@ -385,7 +384,7 @@ class Group(object):
 		l_response = self.check()
 		if l_response["error"] != None: return l_response
 		elif not l_response["exists"]:
-			return r3sponse.error(f"Group [{self.name}] does not exists.")
+			return Response.error(f"Group [{self.name}] does not exists.")
 
 		# handle linux.
 		to_delete, to_add  = [], []
@@ -413,10 +412,10 @@ class Group(object):
 
 		# handle macos.
 		elif OS in ["macos"]:
-			return r3sponse.error(f"Unsupported operating system [{OS}].")
+			return Response.error(f"Unsupported operating system [{OS}].")
 
 		# success.
-		return r3sponse.success(f"Successfully added {len(to_add)} & removed {len(to_delete)} users from group [{self.name}].")
+		return Response.success(f"Successfully added {len(to_add)} & removed {len(to_delete)} users from group [{self.name}].")
 
 		#
 
